@@ -19,7 +19,7 @@ https://github.com/maxbachmann/RapidFuzz/tree/460d291a38922c7fead920de8147798b81
 
 
 **Author**
-    Brian Skinn (bskinn@alum.mit.edu)
+    Brian Skinn (brian.skinn@gmail.com)
 
 **File Created**
     11 Dec 2021
@@ -31,10 +31,14 @@ https://github.com/maxbachmann/RapidFuzz/tree/460d291a38922c7fead920de8147798b81
     https://github.com/bskinn/sphobjinv
 
 **Documentation**
-    https://sphobjinv.readthedocs.io/en/latest
+    https://sphobjinv.readthedocs.io/en/stable
 
 **License**
-    The MIT License; see |license_txt|_ for full license terms
+    Code: `MIT License`_
+
+    Docs & Docstrings: |CC BY 4.0|_
+
+    See |license_txt|_ for full license terms.
 
 **Members**
 
